.. _core_email_setup:

Setup
-----

The following settings are required to allow Peek to send emails.

----

:Email Sender: This is the email address that emails from Peek will be from.

:Email SMTP Server: This is the SMTP server where Peek will connect to and send emails
    via.

:Email Enabled: Should peek actually send the email?

:SMS Email Postfix: This is the SMS gateway domain :code:`@smsgateway.com`.

:SMS Enabled: Should peek actually send the SMS?


----

.. image:: settings.png

